@@ -1,4 +1,4 @@
 pub mod can_helper;
-pub mod cell_helper;
+pub mod eeprom_helper;
 pub mod heap_helper;
 pub mod type_helper;
