@@ -15,8 +15,8 @@ use stm32f1xx_hal_bxcan::timer::{CountDownTimer, Event, Timer};
 use ross_eeprom::DeviceInfo;
 use ross_logger::{log_debug, log_error, log_warning, Logger};
 use ross_protocol::convert_packet::ConvertPacket;
-use ross_protocol::event::bcm_event::*;
-use ross_protocol::event::general_event::AckEvent;
+use ross_protocol::event::bcm::*;
+use ross_protocol::event::general::AckEvent;
 
 use crate::helper::type_helper::{BcmClockPin, BcmDataPin, BcmLatchPin, BcmSpi, CanProtocol};
 use crate::module::*;
