@@ -10,7 +10,7 @@ use embedded_hal::digital::v2::InputPin;
 use ross_eeprom::DeviceInfo;
 use ross_logger::{log_debug, log_error, Logger};
 use ross_protocol::convert_packet::ConvertPacket;
-use ross_protocol::event::button_event::{ButtonPressedEvent, ButtonReleasedEvent};
+use ross_protocol::event::button::{ButtonPressedEvent, ButtonReleasedEvent};
 
 use crate::helper::type_helper::CanProtocol;
 use crate::module::*;
