@@ -7,8 +7,8 @@ use core::cell::RefCell;
 use ross_eeprom::DeviceInfo;
 use ross_logger::{log_debug, log_error, Logger};
 use ross_protocol::convert_packet::*;
-use ross_protocol::event::bootloader_event::BootloaderHelloEvent;
-use ross_protocol::event::programmer_event::ProgrammerHelloEvent;
+use ross_protocol::event::bootloader::BootloaderHelloEvent;
+use ross_protocol::event::programmer::ProgrammerHelloEvent;
 
 use crate::helper::type_helper::CanProtocol;
 use crate::module::*;
