@@ -8,8 +8,8 @@ use core::cell::RefCell;
 use ross_eeprom::DeviceInfo;
 use ross_logger::{log_debug, log_error, log_warning, Logger};
 use ross_protocol::convert_packet::*;
-use ross_protocol::event::configurator_event::*;
-use ross_protocol::event::programmer_event::ProgrammerHelloEvent;
+use ross_protocol::event::configurator::ConfiguratorHelloEvent;
+use ross_protocol::event::programmer::ProgrammerHelloEvent;
 use ross_protocol::packet::Packet;
 use ross_protocol::protocol::BROADCAST_ADDRESS;
 
